To move the list iterator variable into the list_for_each_entry_*()
macro in the future it should be avoided to use the list iterator
variable after the loop body.

To *never* use the list iterator variable after the loop it was
concluded to use a separate iterator variable instead of a
found boolean [1].

This removes the need to use a found variable and simply checking if
the variable was set, can determine if the break/goto was hit.

Link: 
https://lore.kernel.org/all/CAHk-=wgRr_D8CB-D9Kg-c=ehreask5sqxpwr9y7k9sa6cwx...@mail.gmail.com/
 [1]
Signed-off-by: Jakob Koschel <jakobkosc...@gmail.com>
---
 drivers/net/dsa/mv88e6xxx/chip.c | 21 ++++++++++-----------
 1 file changed, 10 insertions(+), 11 deletions(-)

diff --git a/drivers/net/dsa/mv88e6xxx/chip.c b/drivers/net/dsa/mv88e6xxx/chip.c
index 64f4fdd02902..f254f537c357 100644
--- a/drivers/net/dsa/mv88e6xxx/chip.c
+++ b/drivers/net/dsa/mv88e6xxx/chip.c
@@ -1381,28 +1381,27 @@ static int mv88e6xxx_set_mac_eee(struct dsa_switch *ds, 
int port,
 /* Mask of the local ports allowed to receive frames from a given fabric port 
*/
 static u16 mv88e6xxx_port_vlan(struct mv88e6xxx_chip *chip, int dev, int port)
 {
+       struct dsa_port *dp = NULL, *iter, *other_dp;
        struct dsa_switch *ds = chip->ds;
        struct dsa_switch_tree *dst = ds->dst;
-       struct dsa_port *dp, *other_dp;
-       bool found = false;
        u16 pvlan;
 
        /* dev is a physical switch */
        if (dev <= dst->last_switch) {
-               list_for_each_entry(dp, &dst->ports, list) {
-                       if (dp->ds->index == dev && dp->index == port) {
-                               /* dp might be a DSA link or a user port, so it
+               list_for_each_entry(iter, &dst->ports, list) {
+                       if (iter->ds->index == dev && iter->index == port) {
+                               /* iter might be a DSA link or a user port, so 
it
                                 * might or might not have a bridge.
-                                * Use the "found" variable for both cases.
+                                * Set the "dp" variable for both cases.
                                 */
-                               found = true;
+                               dp = iter;
                                break;
                        }
                }
        /* dev is a virtual bridge */
        } else {
-               list_for_each_entry(dp, &dst->ports, list) {
-                       unsigned int bridge_num = dsa_port_bridge_num_get(dp);
+               list_for_each_entry(iter, &dst->ports, list) {
+                       unsigned int bridge_num = dsa_port_bridge_num_get(iter);
 
                        if (!bridge_num)
                                continue;
@@ -1410,13 +1409,13 @@ static u16 mv88e6xxx_port_vlan(struct mv88e6xxx_chip 
*chip, int dev, int port)
                        if (bridge_num + dst->last_switch != dev)
                                continue;
 
-                       found = true;
+                       dp = iter;
                        break;
                }
        }
 
        /* Prevent frames from unknown switch or virtual bridge */
-       if (!found)
+       if (!dp)
                return 0;
 
        /* Frames from DSA links and CPU ports can egress any local port */
-- 
2.25.1

Reply via email to